@@ -82,6 +82,14 @@ class AllWise(CatalogdbModel):
         table_name = 'allwise'
 
 
+class BailerJonesEDR3(CatalogdbModel):
+
+    source_id = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'bailer_jones_edr3'
+
+
 class EROSITASupersetAGN(CatalogdbModel):
 
     pkey = BigIntegerField(primary_key=True)
@@ -246,6 +254,21 @@ class Sagitta(CatalogdbModel):
         table_name = 'sagitta'
 
 
+class SagittaEDR3(CatalogdbModel):
+
+    source_id = BigIntegerField(primary_key=True)
+
+    gaia_dr2 = ForeignKeyField(
+        model=Gaia_DR2,
+        field='source_id',
+        column_name='source_id',
+        object_id_name='source_id',
+        backref='+')
+
+    class Meta:
+        table_name = 'sagitta_edr3'
+
+
 class SDSSV_Plateholes_Meta(CatalogdbModel):
 
     yanny_uid = BigIntegerField(primary_key=True)
@@ -401,6 +424,36 @@ class SDSS_DR16_QSO(SDSS_DR14_QSO):
         table_name = 'sdss_dr16_qso'
 
 
+class SDSS_DR17_APOGEE_Allplates(CatalogdbModel):
+
+    class Meta:
+        table_name = 'sdss_dr17_apogee_allplates'
+
+
+class SDSS_DR17_APOGEE_Allstarlite(CatalogdbModel):
+
+    class Meta:
+        table_name = 'sdss_dr17_apogee_allstarlite'
+
+
+class SDSS_DR17_APOGEE_Allstar(CatalogdbModel):
+
+    class Meta:
+        table_name = 'sdss_dr17_apogee_allstar'
+
+
+class SDSS_DR17_APOGEE_Allvisit(CatalogdbModel):
+
+    class Meta:
+        table_name = 'sdss_dr17_apogee_allvisit'
+
+
+class SDSS_DR17_APOGEE_Allstarmerge(CatalogdbModel):
+
+    class Meta:
+        table_name = 'sdss_dr17_apogee_allstarmerge'
+
+
 class unWISE(CatalogdbModel):
 
     unwise_objid = TextField(primary_key=True)
@@ -1361,6 +1414,14 @@ class Skies_v1(CatalogdbModel):
         table_name = 'skies_v1'
 
 
+class Skies_v2(CatalogdbModel):
+
+    pix_32768 = BigIntegerField(primary_key=True)
+
+    class Meta:
+        table_name = 'skies_v2'
+
+
 class SuperCosmos(CatalogdbModel):
 
     objid = BigIntegerField(primary_key=True)
